[−][src]Trait executors::common::CanExecute
A minimal trait for task executors.
This is mostly useful as a narrowed view for dynamic executor references.
Required methods
fn execute_job(&self, job: Box<dyn FnOnce() + Send + 'static>)
Executes the function job on the Executor.
This is the same as execute, but already boxed up.
Implementors
impl CanExecute for executors::crossbeam_channel_pool::ThreadPool[src]
fn execute_job(&self, job: Box<dyn FnOnce() + Send + 'static>)[src]
impl CanExecute for RunNowExecutor[src]
fn execute_job(&self, job: Box<dyn FnOnce() + Send + 'static>)[src]
impl CanExecute for ThreadPoolExecutor[src]
fn execute_job(&self, job: Box<dyn FnOnce() + Send + 'static>)[src]
impl<P> CanExecute for executors::crossbeam_workstealing_pool::ThreadPool<P> where
P: Parker + Clone + 'static, [src]
P: Parker + Clone + 'static,