Struct executors::crossbeam_workstealing_pool::ThreadPool[][src]

pub struct ThreadPool { /* fields omitted */ }

Methods

impl ThreadPool
[src]

Creates a new thread pool capable of executing threads number of jobs concurrently.

Panics

This function will panic if threads is 0.

Examples

Create a new thread pool capable of executing four jobs concurrently:

use executors::*;
use executors::crossbeam_workstealing_pool::ThreadPool;

let pool = ThreadPool::new(4);