Module numa_utils

Module numa_utils 

This module contains helpers for executors that are NUMA-ware.

In particular the ProcessingUnitDistance code, which allows a the description of costs associated with schedulling a function on a different processing unit than it was originally assigned to.

Structs

ProcessingUnitDistance
A full distance matrix between all processing units on a system

Functions

equidistance
Trivial distance function for non-NUMA architectures