Struct executors::run_now::RunNowExecutor [−][src]
pub struct RunNowExecutor { /* fields omitted */ }Methods
impl RunNowExecutor[src]
impl RunNowExecutorpub fn new() -> RunNowExecutor[src]
pub fn new() -> RunNowExecutorTrait Implementations
impl Clone for RunNowExecutor[src]
impl Clone for RunNowExecutorfn clone(&self) -> RunNowExecutor[src]
fn clone(&self) -> RunNowExecutorReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Executor for RunNowExecutor[src]
impl Executor for RunNowExecutorfn execute<F>(&self, job: F) where
F: FnOnce() + Send + 'static, [src]
fn execute<F>(&self, job: F) where
F: FnOnce() + Send + 'static, Executes the function job on the Executor. Read more
fn shutdown_async(&self)[src]
fn shutdown_async(&self)Shutdown the Executor without waiting. Read more
fn shutdown_borrowed(&self) -> Result<(), String>[src]
fn shutdown_borrowed(&self) -> Result<(), String>Same as shutdown but without consuming self Read more
fn shutdown(self) -> Result<(), String>[src]
fn shutdown(self) -> Result<(), String>Shutdown an Executor and wait for it to shut down all workers. Read more