pub struct ThreadPoolExecutor { /* private fields */ }Expand description
A handle to a threadpool_executor
See module level documentation for usage information.
Implementations
Sourceimpl ThreadPoolExecutor
impl ThreadPoolExecutor
Sourcepub fn new(threads: usize) -> ThreadPoolExecutor
pub fn new(threads: usize) -> ThreadPoolExecutor
Creates a new thread pool capable of executing threads number of jobs concurrently.
Panics
This function will panic if threads is 0.
Examples
Create a new thread pool capable of executing four jobs concurrently:
use executors::*;
use executors::threadpool_executor::ThreadPoolExecutor;
let pool = ThreadPoolExecutor::new(4);Trait Implementations
Sourceimpl CanExecute for ThreadPoolExecutor
impl CanExecute for ThreadPoolExecutor
Sourceimpl Clone for ThreadPoolExecutor
impl Clone for ThreadPoolExecutor
Sourcefn clone(&self) -> ThreadPoolExecutor
fn clone(&self) -> ThreadPoolExecutor
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ThreadPoolExecutor
impl Debug for ThreadPoolExecutor
Sourceimpl Default for ThreadPoolExecutor
Create a thread pool with one thread per CPU.
On machines with hyperthreading,
this will create one thread per hyperthread.
impl Default for ThreadPoolExecutor
Create a thread pool with one thread per CPU. On machines with hyperthreading, this will create one thread per hyperthread.