pub fn execute_locally<F>(job: F) -> Result<(), F>where F: FnOnce() + Send + 'static,
Try to append the job to the thread-local job queue
This only work if called from a thread that is part of the pool. Otherwise the job will be returned in an Err variant.
Err