Support for Rust’s futures and async/await APIs
This functionality is provided via the FuturesExecutor trait, which is implemented for all executors in this crate that can efficiently support it.
Traits
- Futures
Executor - A trait for spawning futures on an Executor
Type Aliases
- Join
Handle - A future that can be used to await the result of a spawned future